@@ -116,7 +116,7 @@ class BitmexOrder:
         self.props = {}
         for symbol in symbols:
             self.props[symbol] = {
-                'stoploss_id': '', 'entry': .0, 'SL': .0, 'TP': .0, 'open': False, 'wait_stop': False, 'qty': 0}
+                'stoploss_id': '', 'stop_id': '', 'entry': .0, 'SL': .0, 'TP': .0, 'open': False, 'wait_stop': False, 'qty': 0}
 
     def check_open_bot_order(self, symbol, entry, sl):
         settings = pickle.load(open(self._settings_path, 'rb'))
@@ -179,12 +179,12 @@ class BitmexOrder:
         elif symbol == 'ETHUSD':
             return round(price * 20) / 20
         else:
-            print('Not a valid symbole for price decimal rounding.')
+            print('{} is not a valid symbol for price decimal rounding.'.format(symbol))
             sys.exit()
 
     def calc_pos_size(self, symbol, sl_distance):
         acc_balance = self.client.acc_balance
-        ps = self.settings.symbols[symbol]['position_size']
+        ps = float(self.settings.symbols[symbol]['position_size'])
         if symbol == 'XBTUSD':
             btc_usd = self.client.last_current_price(symbol)
             lot_step = 100
@@ -232,13 +232,13 @@ class BitmexOrder:
         self.order_cancel(self.props[symbol]['stoploss_id'])
 
     def stoporder_cancel(self, symbol):
-        self.order_cancel(self.props[symbol].stop_id)
+        self.order_cancel(self.props[symbol]['stop_id'])
 
     def bracket_stop_order(self, symbol, orderQty, entry, sl, tp=0):
         try:
-            self.props[symbol].stop_id = self.generate_id(symbol)
+            self.props[symbol]['stop_id'] = self.generate_id(symbol)
             order_res = self.client.client.Order.Order_new(
-                symbol=symbol, ordType='Stop', clOrdID=self.props[symbol].stop_id, orderQty=orderQty,
+                symbol=symbol, ordType='Stop', clOrdID=self.props[symbol]['stop_id'], orderQty=orderQty,
                 stopPx=self.price_decimals(symbol, entry), execInst='LastPrice'
             ).result()
             self.props[symbol]['qty'] = orderQty
